@@ -3,21 +3,24 @@ import sys
 
 import mio
 from mio import runtime
+from mio.utils import method
 from mio.object import Object
-from mio.utils import method, Null
+
+
+from .file import File
 
 
 class System(Object):
 
-    def __init__(self, value=Null):
-        super(System, self).__init__(value=value)
+    def __init__(self):
+        super(System, self).__init__()
 
         self["args"] = self.build_args()
         self["version"] = runtime.find("String").clone((mio.__version__))
 
-        self["stdin"] = runtime.find("File").clone(sys.stdin)
-        self["stdout"] = runtime.find("File").clone(sys.stdout)
-        self["stderr"] = runtime.find("File").clone(sys.stderr)
+        self["stdin"] = File(sys.stdin)
+        self["stdout"] = File(sys.stdout)
+        self["stderr"] = File(sys.stderr)
 
         self.create_methods()
         self.parent = runtime.find("Object")
