@@ -123,7 +123,8 @@ class State(object):
         message = None
 
         try:
-            return parse(tokenize(code)).eval(self.root if receiver is None else receiver, self.root if context is None else context, message)
+            message = parse(tokenize(code))
+            return message.eval(self.root if receiver is None else receiver, self.root if context is None else context, message)
         except Error as e:
             from .object import Object
             if e.args and isinstance(e.args[0], Object):
@@ -134,21 +135,35 @@ class State(object):
                 type = e.__class__.__name__
                 message = str(e)
 
-            stack = "\n".join([repr(m) for m in e.stack])
+            stack = "\n".join(["  {0:s}".format(repr(m)) for m in e.stack])
             underline = "-" * (len(type) + 1)
-            print("\n  {0:s}: {1:s}\n  {2:s}\n  {3:s}\n".format(type, message, underline, stack))
+            print("\n  {0:s}: {1:s}\n  {2:s}\n{3:s}\n".format(type, message, underline, stack))
             if reraise:
                 raise
         except Exception as e:  # pragma: no cover
             print("ERROR:", e)
+            from traceback import format_exc
+            print(format_exc())
             if reraise:
                 raise
 
     def load(self, filename, receiver=None, context=None):
         self.eval(open(filename, "r").read(), receiver=receiver, context=context)
 
+    def runsource(self, source):
+        from .utils import format_result
+
+        if not check_parens(source):
+            return True
+
+        result = self.eval(source)
+        if result is not None:
+            output = format_result(result)
+            if output is not None:
+                print("===> {0:s}".format(output))
+
     def repl(self):
-        from .utils import format_result, tryimport
+        from .utils import tryimport
 
         readline = tryimport("readline")
 
@@ -176,7 +191,7 @@ class State(object):
         while True:
             try:
                 if cont:
-                    ps = "..... "
+                    ps = ".... "
                 else:
                     ps = "mio> "
 
@@ -184,11 +199,7 @@ class State(object):
 
                 if code:
                     if check_parens(code):
-                        result = self.eval(code)
-                        if result is not None:  # pragma: no cover
-                            output = format_result(result)
-                            if output is not None:
-                                print("===> {0:s}".format(output))
+                        self.runsource(code)
                         code = ""
                         cont = False
                     else:
