@@ -46,6 +46,11 @@ class List(Object):
         receiver.value.append(item.eval(context))
         return receiver
 
+    @method()
+    def remove(self, receiver, context, m, item):
+        receiver.value.remove(item.eval(context))
+        return receiver
+
     @method()
     def insert(self, receiver, context, m, index, value):
         receiver.value.insert(int(index.eval(context)), value.eval(context))
